Dave Holland: Prism (CD) – jpc
Description: Die CD Dave Holland: Prism jetzt probehören und für 6,99 Euro kaufen. Mehr von Dave Holland (geb. 1946) gibt es im Shop.

Anmelden Konto anlegen

## Dave Holland: Prism

Dave Holland (geb. 1946)
Prism
CD
CD (Compact Disc)

Herkömmliche CD, die mit allen CD-Playern und Computerlaufwerken, aber auch mit den meisten SACD- oder Multiplayern abspielbar ist.

Bewertung:
Artikel am Lager
-22%
EUR 8,99**
EUR 6,99*

## Der Artikel Dave Holland (geb. 1946): Prism wurde in den Warenkorb gelegt.

Ihr Warenkorb enthält nun 1 Artikel im Wert von EUR 6,99.

Zum Warenkorb Weiter einkaufen
Versandkosten (Russian Federation): EUR 5,99

- Neues vom Künstler
- Preisalarm

- Label: OKeh, 2013
- Bestellnummer: 1537284
- Erscheinungstermin: 20.9.2013

### Weitere Ausgaben von Prism

- EUR 19,99* CD
- EUR 23,99* 2 LPs
- EUR 27,99* 2 LPs
- EUR 27,99* CD, (Blu-Spec CD2), Japan-Import

Der englische Jazz-Bassist Dave Holland ist seit über fünf Jahrzehnten ein wichtiger Teil der Jazzszene. Seine Konzerte reichen dabei von Soloauftritten bis hin zu BigBands. Er hat schon mit den größten Jazzern aller Zeiten gespielt. Darunter auch Miles Davis mit dem er, als Teil der Rhytmusgruppe, drei Alben aufgenommen hat, die alle wegweisend für den Fusion Jazz waren.
Für sein neuestes Album hat sich Holland mit Kevon Eubanks (Gitarre), Craig Taborn (Piano), Fender Rhodes und Eric Harland (Drums) zusammengetan - alle Meister ihres Fachs. Jeder der fünf Musiker hat eigene Kompositionen beigesteuert. So ist im Ergebnis ein elektrisierendes Album mit einem unwiderstehlichen Groove entstanden, mit dem Holland eine neue musikalische Richtung einschlägt. "Prism" führt den Hörer durch viele musikalische Landschaften wie dem funkigen Song "The Watcher" oder "The Empty Chair", der mit seinem Soul-Blues an Jimi Hendrix erinnert.

### Rezensionen

,,Man hört dem Team die Lust am gemeinsamen Abheben an, ohne dass einerseits die Abstraktionsfähigkeit, andererseits die Individualität der Beteiligten verloren geht. Kraftvoll, grandios!" (Audio, November 2013)

- Tracklisting
- Mitwirkende

1. 1
   The Watcher
2. 2
   The Empty Chair (For Clare)
3. 3
   Spirals
4. 4
   Choir
5. 5
   The Color of Iris
6. 6
   A New Day
7. 7
   The True Meaning of Determination
8. 8
   Evolution
9. 9
   Breathe

### Bestell-Hotline

0180 508 508 1

Montag bis Samstag
von 8:00 bis 20:00 Uhr

0,14 EUR/Minute aus dem deutschen Festnetz, Mobilfunkhöchstpreis 0,42 EUR/Minute

### Mehr von Dave Holland (g...

-20%
Dave Holland
Pass It On
EUR 9,99**
CD
EUR 7,99*
-20%
Dave Holland
Extensions
EUR 9,99**
CD
EUR 7,99*
-15%
Dave Holland
Not For Nothin'
EUR 18,99**
CD
EUR 15,99*
-20%
Dave Holland
Dream Of The Elders
EUR 19,99**
CD
EUR 15,99*
-10%
Dave Holland
Pathways
EUR 37,99**
CD
EUR 33,99*
alle anzeigen

### Dazu passend

#### Andere Kunden kauften auch diese Artikel

-41%
Al Di Meola
All Your Life - A Tribute To The Beatles
EUR 16,99**
CD
EUR 9,99*
-30%
Al Di Meola
World Sinfonia
EUR 9,99**
CD
EUR 6,99*
Dhafer Youssef
Birds Requiem
CD
EUR 8,99*
Charlie Haden & Jim Hall
Charlie Haden & Jim Hall
CD
EUR 15,99*
-41%
Paul Motian
Garden Of Eden
EUR 17,99**
CD
EUR 10,49*

### Bewertungen und Rezensionen

4,1 von 5
Musik:
4 von 5
Klang:
4 von 5
1 von 1 (100%) würden dieses Produkt empfehlen.
Bewertungsübersicht (8 Bewertungen)

5 Sterne |  | 4
4 Sterne |  | 2
3 Sterne |  | 1
2 Sterne |  | 1
1 Stern |  |

- 4 von 5
  Aro
  1. Ort: Stuttgart
  2. Alter: 35 bis 44
  3. Geschlecht: Männlich
  27. März 2014
  Musik:
  4 von 5
  Klang:
  4 von 5
  Vier Meister am Werk
  Eine sehr gute CD von vier Musikern, die es einfach drauf haben. Überwiegend eher ruhig und entspannt, mit ein paar schnelleren, groovigeren Stücken dazwischen, schaffen die vier eine hervorragende Atmosphäre und tragen in ihren Soli nie zu dick auf. Toller Modern Jazz, der nie nervt und nie belanglos ist. Insbesondere Gitarrist Kevin Eubanks überzeugt mich. Die CD klingt obendrein ausgezeichnet.

Alle Rezensionen anzeigen

## Möchten Sie sich anmelden?

Ohne Anmeldung wird Ihre Rezension anonym veröffentlicht. Anonyme Rezensionen nehmen nicht an der monatlichen Verlosungsaktion teil.

Bitte überprüfen Sie Ihre Zugangsdaten
E-Mail oder Kundennummer Passwort Passwort vergessen?

Neukunde?
» Jetzt Konto einrichten

© jpc-schallplatten Versandhandelsgesellschaft mbH